Crate kcr_secretgenerator_mittwald_de

Crate kcr_secretgenerator_mittwald_de 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the secretgenerator.mittwald.de group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

secretgenerator.mittwald.de/v1alpha1

  • BasicAuth
  • SSHKeyPair
  • StringSecret

Modules

v1alpha1